@@ -760,6 +760,7 @@ types: list[str] = [
     "AWS::SecretsManager::SecretTargetAttachment",
     "AWS::SecurityHub::AutomationRule",
     "AWS::SecurityHub::AutomationRuleV2",
+    "AWS::SecurityHub::ConnectorV2",
     "AWS::SecurityHub::DelegatedAdmin",
     "AWS::SecurityHub::Hub",
     "AWS::SecurityHub::HubV2",
@@ -1254,6 +1255,7 @@ cached: list[str] = [
     "aws-glue-datacatalogencryptionsettings.json",
     "aws-glue-dataqualityruleset.json",
     "aws-glue-devendpoint.json",
+    "aws-glue-identitycenterconfiguration.json",
     "aws-glue-job.json",
     "aws-glue-mltransform.json",
     "aws-glue-partition.json",
@@ -1328,7 +1330,6 @@ cached: list[str] = [
     "aws-lambda-layerversionpermission.json",
     "aws-lambda-permission.json",
     "aws-lambda-url.json",
-    "aws-lambda-version.json",
     "aws-launchwizard-deployment.json",
     "aws-lightsail-alarm.json",
     "aws-lightsail-bucket.json",
@@ -1479,8 +1480,8 @@ cached: list[str] = [
     "aws-rum-appmonitor.json",
     "aws-s3-accessgrant.json",
     "aws-s3-accessgrantsinstance.json",
+    "aws-s3-accessgrantslocation.json",
     "aws-s3-accesspoint.json",
-    "aws-s3-bucket.json",
     "aws-s3-bucketpolicy.json",
     "aws-s3-multiregionaccesspoint.json",
     "aws-s3-multiregionaccesspointpolicy.json",
@@ -1491,8 +1492,6 @@ cached: list[str] = [
     "aws-s3outposts-bucketpolicy.json",
     "aws-s3outposts-endpoint.json",
     "aws-s3tables-namespace.json",
-    "aws-s3tables-table.json",
-    "aws-s3tables-tablebucket.json",
     "aws-s3tables-tablebucketpolicy.json",
     "aws-s3tables-tablepolicy.json",
     "aws-sagemaker-app.json",
@@ -1526,6 +1525,7 @@ cached: list[str] = [
     "aws-secretsmanager-secrettargetattachment.json",
     "aws-securityhub-automationrule.json",
     "aws-securityhub-automationrulev2.json",
+    "aws-securityhub-connectorv2.json",
     "aws-securityhub-delegatedadmin.json",
     "aws-securityhub-hub.json",
     "aws-securityhub-hubv2.json",
